@@ -50,7 +50,7 @@ similar solutions like this...)
 use warnings;
 use strict;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 METHODS
 
@@ -100,6 +100,12 @@ check running processes
 
 query dns server and check for the answers
 
+check also if the dns responses are fast enought
+
+=item 02_disk-free.t
+
+disk free/full check
+
 =item 02_resolv.conf.t
 
 query all nameserver-s in /etc/resolv.conf and make sure all are reachable.
@@ -110,6 +116,12 @@ compare local machine time with a ntp server to make sure both are in the sync.
 
 For the idea thanks to Emmanuel Rodriguez Santiago.
 
+=item 02_messages.t
+
+Checks a file(s) and generates failed tests on every line found there.
+Allows any program in the system to pass messages to the monitoring simply by
+adding line into a file
+
 =item 03_sites-ok.t
 
 check web sites
@@ -124,6 +136,34 @@ Check the output of the shell command with a regexp. Check the exit code.
 
 For the idea thanks to Aldo Calpini.
 
+=item 03_find-huge-files.t
+
+Check folders it there are not too many files and if the files (logs, tmp,
+etc.) didn't grow too large.
+
+=item 03_folder-file.t
+
+File directory permissions and sizes for a directories
+(e.g. Is cache dir writeable for httpd)
+
+For the idea thanks to Peter Hartl.
+
+=item 03_interfaces-ptr.t
+
+check if interfaces has a PTR record which properly resolves back to interface ip
+
+=item 03_wakeup.t
+
+After given number of days a fail test will occure. The purpose is to make sure
+monitoring team is receiving alarms properly. If the admins finds out that this
+test fails for couple of days without anyone notice then there is something
+wrong.
+
+=item 03_net-hops.t
+
+Does traceroute and check first or last N network hops to the host. It's using system
+C<traceroute> program.
+
 =back
 
 =head1 sky
@@ -131,18 +171,16 @@ For the idea thanks to Aldo Calpini.
 There are no restrictions in Perl and there are no best solutions => so the
 sky is the limit! (Or we our self are the limit?)
 
+=head1 INSTALL
+
+Check out the F<Build.PL> for the list of examples that are installed in F</etc/t>.
+
 =head1 TODO
 
 Any wishes || good ideas for general server tests should go here.
 Do you have any? Send it! Or even better send the .t file.
 
-	* check if all the interfaces has dns revers rr that properly resolves back
-	* I should write some easy example test for non perl admins
-	* file directory permissions for all relevant application directories
-	  (e.g. Is cache dir writeable for httpd) (thanks Peter Hartl)
-	* check folders if the files (logs?) didn't grow too huge
-	
-	* create Test::Server::Smoke to try examples on smoke testing servers
+	* connect to database and check if count of rows in all table doesn't exceed some number
 
 =head1 LINKS
 
@@ -150,6 +188,9 @@ L<http://testanything.org/>,
 L<http://en.wikipedia.org/wiki/Test_Anything_Protocol>
 and a book "Perl Testing: A Developer's Notebook"
 
+And if you like automated "thinks" check out also L<Sysadm::Install>
+for system admin scripting.
+
 =head1 AUTHOR
 
 Jozef Kutej
